@@ -1,15 +1,18 @@
 use strict; use warnings;
 package Inline;
 
-our $VERSION = '0.76';
+our $VERSION = '0.81';
 
 use Inline::denter;
 use Config;
 use Carp;
 use Cwd qw(abs_path cwd);
+use Encode;
 use File::Spec;
 use File::Spec::Unix;
 use Fcntl qw(LOCK_EX LOCK_UN);
+use version;
+use utf8;
 
 my %CONFIG = ();
 my @DATA_OBJS = ();
@@ -79,10 +82,15 @@ sub SAFEMODE {$safemode}
 # This is where everything starts.
 #==============================================================================
 sub import {
+    my $class = shift;
+    $class->import_heavy(@_);
+}
+
+sub import_heavy {
     local ($/, $") = ("\n", ' '); local ($\, $,);
 
     my $o;
-    my ($pkg, $script) = caller;
+    my ($pkg, $script) = caller(1);
     # Not sure what this is for. Let's see what breaks.
     # $pkg =~ s/^.*[\/\\]//;
     my $class = shift;
@@ -298,11 +306,13 @@ sub push_overrides {
     my ($language_id) = $o->{API}{language_id};
     my ($ilsm) = $o->{INLINE}{ILSM_module};
     for (@{$o->{CONFIG}{USING}}) {
+        my $fixed_name = /^Parser?(Pegex|RegExp|RecDescent)$/ ? "Parser::$1" : $_;
+        $fixed_name =~ s/^:://;
         my $using_module = /^::/
-                           ? "Inline::$language_id$_"
+                           ? "Inline::${language_id}::$fixed_name"
                            : /::/
                              ? $_
-                             : "Inline::${language_id}::$_";
+                             : "Inline::${language_id}::$fixed_name";
         eval "require $using_module";
         croak "Invalid module '$using_module' in USING list:\n$@" if $@;
         my $register;
@@ -388,7 +398,8 @@ sub check_config {
                   unless $value =~ /^[a-zA-Z_](\w|::)*$/;
             }
             elsif ($key eq 'VERSION') {
-                croak M13_usage_VERSION($value) unless $value =~ /^\d\.\d\d*$/;
+                croak M13_usage_VERSION($value)
+                    unless version::is_lax($value);
             }
             $o->{CONFIG}{$key} = $value;
         }
@@ -452,7 +463,11 @@ sub check_installed {
     $o->{INLINE}{object_ready} = 0;
     unless ($o->{API}{code} =~ /^[A-Fa-f0-9]{32}$/) {
         require Digest::MD5;
-        $o->{INLINE}{md5} = Digest::MD5::md5_hex($o->{API}{code});
+        my $encoded_code = $o->{API}{code};
+        if ( utf8::is_utf8($encoded_code)) {
+            $encoded_code = Encode::encode_utf8($encoded_code);
+        }
+        $o->{INLINE}{md5} = Digest::MD5::md5_hex($encoded_code);
     }
     else {
         $o->{INLINE}{md5} = $o->{API}{code};
@@ -814,7 +829,7 @@ sub create_config_file {
         # Inline::CPP (and perhaps other Inline modules) will fail because P::RD isn't found.
         my @_inc = map { "-I$_" }
        ($inline,
-        grep {(-d File::Spec->catdir($_,"Inline") or -d File::Spec->catdir($_,"auto","Inline") or -e File::Spec->catdir($_,"Parse/RecDescent.pm"))} @INC);
+        grep {(-d File::Spec->catdir($_,"Inline") or -d File::Spec->catdir($_,"auto","Inline") or -e File::Spec->catdir($_,"Win32/Mutex.pm") or -e File::Spec->catdir($_,"Parse/RecDescent.pm"))} @INC);
        system $perl, @_inc, "-MInline=_CONFIG_", "-e1", "$dir"
           and croak M20_config_creation_failed($dir);
         return;
@@ -1529,8 +1544,7 @@ END
 sub M13_usage_VERSION {
     my ($version) = @_;
     return <<END;
-Invalid value for VERSION config option: '$version'
-Must be of the form '#.##'.
+Invalid (according to version.pm) VERSION config option: '$version'
 (Should also be specified as a string rather than a floating point number)
 
 END
